#include "icmun.ih"

void fun_div ()
{
    puts ("        div");
}
